@@ -1,11 +1,11 @@
 use clap::Parser;
 use std::fs::File;
 use std::io::BufReader;
-use tokio::process::Command;
 use console::style;
 use gcloud_utils::cli::{Cli, Commands, GcpConfig, IamCommands, ComputeCommands, InitCommands, GhCommands, RunCommands};
 use gcloud_utils::gh::*;
 use gcloud_utils::iam::*;
+use gcloud_utils::compute::*;
 use gcloud_utils::init::*;
 use gcloud_utils::run::*;
 use std::path::Path;
@@ -23,20 +23,19 @@ async fn main() {
     let f = File::open(file_name).unwrap();
     let reader = BufReader::new(f);
     let gcp: GcpConfig = serde_json::from_reader(reader).unwrap();
-    config_set(&gcp.project_id).await;
     match cli.command {
         Commands::Iam(iam) => {
             let iam_cmd = iam.command.unwrap_or(IamCommands::Help);
             match iam_cmd {
                 IamCommands::Setup => {
-                    process_create_service_account(gcp.service_name.as_str()).await;
+                    process_create_service_account(gcp.project_id.as_str(), gcp.service_name.as_str()).await;
                     process_create_service_account_key(
-                        gcp.service_name.as_str(),
                         gcp.project_id.as_str(),
+                        gcp.service_name.as_str(),
                     )
                     .await;
-                    process_add_roles(gcp.service_name.as_str(), gcp.project_id.as_str()).await;
-                    process_enable_permissions().await;
+                    process_add_roles(gcp.project_id.as_str(), gcp.service_name.as_str()).await;
+                    process_enable_permissions(gcp.project_id.as_str()).await;
                 }
                 _ => {
                     println!("{}{}", PAPER_EMOJI, style("To see example;\n\n $gcu iam --help").white().bold());
@@ -47,8 +46,8 @@ async fn main() {
             let run_cmd = run.command.unwrap_or(RunCommands::Help);
             match run_cmd {
                 RunCommands::Deploy => {
-                    process_build(&gcp.service_name, &gcp.project_id).await;
-                    process_deploy(&gcp.service_name, &gcp.project_id).await;
+                    process_build(&gcp.project_id, &gcp.service_name).await;
+                    process_deploy(&gcp.project_id, &gcp.service_name).await;
                 }
                 _ => {
                     println!("{}{}", PAPER_EMOJI, style("To see example;\n\n $gcu run --help").white().bold());
@@ -81,14 +80,14 @@ async fn main() {
             let compute_cmd = compute.command.unwrap_or(ComputeCommands::Help);
             match compute_cmd {
                 ComputeCommands::CreateNat => {
-                    process_create_service_account(gcp.service_name.as_str()).await;
-                    process_create_service_account_key(
-                        gcp.service_name.as_str(),
-                        gcp.project_id.as_str(),
-                    )
-                    .await;
-                    process_add_roles(gcp.service_name.as_str(), gcp.project_id.as_str()).await;
-                    process_enable_permissions().await;
+                    process_create_network(&gcp.project_id, &gcp.service_name).await;
+                    process_create_firewall_tcp(&gcp.project_id, &gcp.service_name).await;
+                    process_create_firewall_ssh(&gcp.project_id, &gcp.service_name).await;
+                    process_create_subnet(&gcp.project_id, &gcp.service_name, &gcp.region).await;
+                    process_create_connector(&gcp.project_id, &gcp.service_name,  &gcp.region).await;
+                    process_create_router(&gcp.project_id, &gcp.service_name, &gcp.region).await;
+                    process_create_external_ip(&gcp.project_id, &gcp.service_name, &gcp.region).await;
+                    process_create_nat(&gcp.project_id, &gcp.service_name, &gcp.region).await;
                 }
                 _ => {
                     println!("{}{}", PAPER_EMOJI, style("To see example;\n\n $gcu compute --help").white().bold());
@@ -96,12 +95,4 @@ async fn main() {
             }
         },
     }
-}
-
-async fn config_set(project_id: &str) {
-    let _output = Command::new("gcloud")
-        .args(&["config", "set", "project", project_id])
-        .output()
-        .await;
-    // println!("output = {:?}", output);
-}
+}
\ No newline at end of file
